summaryrefslogtreecommitdiff
path: root/cli_args.go
diff options
context:
space:
mode:
Diffstat (limited to 'cli_args.go')
-rw-r--r--cli_args.go10
1 files changed, 6 insertions, 4 deletions
diff --git a/cli_args.go b/cli_args.go
index 413245c..4c91f44 100644
--- a/cli_args.go
+++ b/cli_args.go
@@ -10,20 +10,22 @@ import (
"github.com/rfjakob/gocryptfs/internal/tlog"
)
-// argContainer stores the parsed CLI arguments
+// argContainer stores the parsed CLI options and arguments
type argContainer struct {
debug, init, zerokey, fusedebug, openssl, passwd, foreground, version,
plaintextnames, quiet, nosyslog, wpanic,
longnames, allow_other, ro, reverse bool
- masterkey, mountpoint, cipherdir, cpuprofile, config, extpass,
+ masterkey, mountpoint, cipherdir, cpuprofile, extpass,
memprofile, o string
+ // Configuration file name override
+ config string
notifypid, scryptn int
}
var flagSet *flag.FlagSet
-// parseCliArgs - parse command line arguments
-func parseCliArgs() (args argContainer) {
+// parseCliOpts - parse command line options (i.e. arguments that start with "-")
+func parseCliOpts() (args argContainer) {
var err error
var opensslAuto string